@@ -14,4 +14,7 @@ pub struct Opts {
     /// How many cards to be testing on at once
     #[cfg_attr(feature = "clap", clap(long, short))]
     pub testing: Option<usize>,
+    /// Should cards be set to 0 when demoted?
+    #[cfg_attr(feature = "clap", clap(long, short))]
+    pub zeroize: bool,
 }
